@@ -46,6 +46,8 @@ class Recruit:
         }
 
         df = pd.DataFrame(di)
+        df.insert(0, 'Year', year)
+
 
         return df
 
@@ -106,7 +108,7 @@ class Recruit:
         team = []
         pattern = "college/(.*?)/"
 
-        for i in range(20):
+        for i in range(40):
             res = requests.get('https://247sports.com/Season/' + str(year) + '-Football/CompositeRecruitRankings/?ViewPath=~%2FViews%2FSkyNet%2FPlayerSportRanking%2F_SimpleSetForSeason.ascx&InstitutionGroup=HighSchool&Page=' + str(i + 1) + '', headers = {'User-Agent': 'Mozilla/5.0'})
             site = html.fromstring(res.content)
 
@@ -126,7 +128,13 @@ class Recruit:
             hs.extend(x.strip() for x in hs_err)
             citystate = [x.split('(')[1] for x in hometown_err]
             city.extend([x.split(',')[0] for x in citystate])
-            state_err = [x.split(',')[1] for x in citystate]
+            state_err = []
+            for x in citystate:
+                try:
+                    state_err.append(x.split(',')[1])
+                except:
+                    state_err.append('NULL')
+
             state_err = [x.replace(')', '') for x in state_err]
             state.extend([x.strip() for x in state_err])
 
@@ -167,6 +175,8 @@ class Recruit:
         }
 
         df = pd.DataFrame(di)
+        df.insert(0, 'Year', year)
+
 
         return df
 
@@ -184,10 +194,16 @@ class Recruit:
         pos_rank = []
         st_rank = []
 
+        team = []
+        pattern = "college/(.*?)/"
+
         for i in range(20):
             res = requests.get('https://247sports.com/Season/' + str(year) + '-Basketball/CompositeRecruitRankings/?ViewPath=~%2FViews%2FSkyNet%2FPlayerSportRanking%2F_SimpleSetForSeason.ascx&InstitutionGroup=HighSchool&Page=' + str(i + 1) + '', headers = {'User-Agent': 'Mozilla/5.0'})
             site = html.fromstring(res.content)
 
+            status_list = site.xpath("//div[@class='status']")
+
+
             ids = site.xpath("//div[@class='recruit']/a[1]/@href")
             player_id.extend([re.search("([^-]+$)", x).group(1) for x in ids])
             players.extend(site.xpath("//div[@class='recruit']/a[1]/text()"))
@@ -201,7 +217,13 @@ class Recruit:
             hs.extend(x.strip() for x in hs_err)
             citystate = [x.split('(')[1] for x in hometown_err]
             city.extend([x.split(',')[0] for x in citystate])
-            state_err = [x.split(',')[1] for x in citystate]
+            state_err = []
+            for x in citystate:
+                try:
+                    state_err.append(x.split(',')[1])
+                except:
+                    state_err.append('NULL')
+
             state_err = [x.replace(')', '') for x in state_err]
             state.extend([x.strip() for x in state_err])
 
@@ -209,6 +231,20 @@ class Recruit:
             nat_rank.extend(site.xpath("//a[@class='natrank']/text()"))
             pos_rank.extend(site.xpath("//a[@class='posrank']/text()"))
             st_rank.extend(site.xpath("//a[@class='sttrank']/text()"))
+
+            for x in status_list:
+                try:
+                    url = x.xpath("a[1]/@href")
+                    url = url[0]
+                    if re.search(pattern, url):
+                        substring = re.search(pattern, url).group(1)
+                        substring = substring.replace('-', ' ')
+                        team.append(substring)
+                    else:
+                        raise ValueError('Not Committed Yet')
+                except:
+                    team.append('NULL')
+
             time.sleep(2)
 
         di = {
@@ -223,10 +259,62 @@ class Recruit:
         'Rating' : score,
         'National_Rank' : nat_rank,
         'Position_Rank' : pos_rank,
-        'State_Rank' : st_rank
+        'State_Rank' : st_rank,
+        'Team' : team
         }
 
         df = pd.DataFrame(di)
+        df.insert(0, 'Year', year)
+
+
+        return df
+
+    def getDraft(self, year):
+
+        player_id = []
+        player = []
+        position = []
+        rd_pick = []
+        draft_pick = []
+        rd = []
+        rating = []
+
+        for i in range(7):
+            res = requests.get('https://247sports.com/League/NFL/DraftPicks/?year=' + str(year) + '&round=' + str(i+1) + '&mock=0', headers = {'User-Agent': 'Mozilla/5.0'})
+            site = html.fromstring(res.content)
+
+            draft_list = site.xpath("//ul[@class='content-list draft-list league']/li[not(@class)]")
+
+            ids = site.xpath("//div[@class='name']/a[1]/@href")
+            player_id.extend([re.search("([^-]+$)", x).group(1) for x in ids])
+            player.extend(site.xpath("//div[@class='name']/a[1]/text()"))
+            for x in draft_list:
+                try:
+                    position.append(x.xpath("div[@class='list-data left']/ul[@class='metrics-list']/li[1]/text()"))
+                    rd.append(str(i+1))
+                except:
+                    position.append('NULL')
+            rd_pick.extend(site.xpath("//div[@class='pick left']/span[1]/text()"))
+            draft_pick.extend(site.xpath("//div[@class='pick left']/span[2]/text()"))
+            rating.extend(site.xpath("//div[@class='rating']/span[@class='score']/text()"))
+
+            time.sleep(1)
+
+        position = [''.join(x) for x in position] # Turn all entries into strings instead of one length lists
+
+        di = {
+            'ID' : player_id,
+            'Player' : player,
+            'POS' : position,
+            'HS_Rating' : rating,
+            'Round' : rd,
+            'RD_pick' : rd_pick,
+            'Draft_pick' : draft_pick
+        }
+
+        df = pd.DataFrame(di)
+        df['POS'] = df['POS'].replace('', 'NULL')
+        df['HS_Rating'] = df['HS_Rating'].replace(' NA ', 'NULL')
 
         return df
 
